<?php
declare(strict_types=1);

namespace Jiwei\EasyHttpSdk;

use GuzzleHttp\Psr7\Request;
use Jiwei\EasyHttpSdk\Policy\DefaultErrorHandlingPolicy;
use Jiwei\EasyHttpSdk\Policy\HandlingPolicyInterface;

class XXXSDKOption extends Option
{
    private const AUTH_API_ROUTE = "/api/access/token";

    const AUTH_CACHE_EXPIRES_AT = 30000;

    const ENDPONIT_HOSTS = [
        'local' => 'localhost:8080',
        'development' => 'localhost:8080',
        'production' => 'localhost:8080'
    ];

    /**
     * 鉴权模式
     *
     * @return \Closure
     */
    public function authorization(): \Closure
    {
        return function (string $appId, string $appSecret): Request {
            return new Request('post', self::AUTH_API_ROUTE, [
                "body" => json_encode([
                    "app_key" => $appId,
                    "app_secret" => $appSecret
                ])
            ]);
        };
    }

    /**
     * 错误处理策略
     * @return HandlingPolicyInterface
     */
    public function errorHandlingPolicy(): HandlingPolicyInterface
    {
        return new DefaultErrorHandlingPolicy();
    }
}
